searchNodes=[{"ref":"Dinero.html","title":"Dinero","type":"module","doc":"Dinero is a struct that provides methods for working with currencies Examples iex&gt; d1 = Dinero.new(100, :USD) %Dinero{amount: 10000, currency: :USD} iex&gt; d2 = Dinero.new(200, :USD) %Dinero{amount: 20000, currency: :USD} iex&gt; Dinero.add(d1, d2) %Dinero{amount: 30000, currency: :USD} Note: Dinero uses coins value for calculations. So when you create a new Dinero struct with 100 USD it automatically transforms this into 10000 cents"},{"ref":"Dinero.html#add/2","title":"Dinero.add/2","type":"function","doc":"Adds two Dinero structs Examples iex&gt; d1 = Dinero.new(100, :USD) %Dinero{amount: 10000, currency: :USD} iex&gt; d2 = Dinero.new(20, :USD) %Dinero{amount: 2000, currency: :USD} iex&gt; Dinero.add(d1, d2) %Dinero{amount: 12000, currency: :USD}"},{"ref":"Dinero.html#convert/3","title":"Dinero.convert/3","type":"function","doc":"Converts value of Dinero to target currency using exchange_rate Examples iex&gt; d = Dinero.new(100, :USD) %Dinero{amount: 10000, currency: :USD} iex&gt; Dinero.convert(d, :UAH, 26.2) %Dinero{amount: 262000, currency: :UAH} iex&gt; Dinero.convert(d, :USD, 26.2) ** (ArgumentError) target currency must be different from source currency"},{"ref":"Dinero.html#divide/2","title":"Dinero.divide/2","type":"function","doc":"Divides Dinero by a value and rounds the result Examples iex&gt; d = Dinero.new(100.24, :USD) %Dinero{amount: 10024, currency: :USD} iex&gt; Dinero.divide(d, 3) %Dinero{amount: 3341, currency: :USD} iex&gt; Dinero.divide(d, 5) %Dinero{amount: 2005, currency: :USD}"},{"ref":"Dinero.html#multiply/3","title":"Dinero.multiply/3","type":"function","doc":"Multiplies a Dinero by a value. If a multiplier is float you can pass the third boolean param to round up (true) or truncate (false, default) the result Examples iex&gt; d = Dinero.new(120, :USD) %Dinero{amount: 12000, currency: :USD} iex&gt; Dinero.multiply(d, 4) %Dinero{amount: 48000, currency: :USD} iex&gt; d = Dinero.new(100, :USD) %Dinero{amount: 10000, currency: :USD} iex&gt; Dinero.multiply(d, 1.005, true) %Dinero{amount: 10050, currency: :USD} iex&gt; Dinero.multiply(d, 1.005) %Dinero{amount: 10049, currency: :USD}"},{"ref":"Dinero.html#new/2","title":"Dinero.new/2","type":"function","doc":"Creates a new Dinero struct with provided currency. If currency is not supported, ArgumentError will be raised Examples iex&gt; Dinero.new(100, :USD) %Dinero{amount: 10000, currency: :USD} iex&gt; Dinero.new(100, :RUR) ** (ArgumentError) currency RUR not found"},{"ref":"Dinero.html#subtract/2","title":"Dinero.subtract/2","type":"function","doc":"Subtracts one Dinero from another Examples iex&gt; d1 = Dinero.new(100, :USD) %Dinero{amount: 10000, currency: :USD} iex&gt; d2 = Dinero.new(20, :USD) %Dinero{amount: 2000, currency: :USD} iex&gt; Dinero.subtract(d1, d2) %Dinero{amount: 8000, currency: :USD}"},{"ref":"Dinero.html#t:t/0","title":"Dinero.t/0","type":"type","doc":""},{"ref":"Dinero.Currency.html","title":"Dinero.Currency","type":"module","doc":"Provides functions to work with supported currencies"},{"ref":"Dinero.Currency.html#all/0","title":"Dinero.Currency.all/0","type":"function","doc":"Returns all supported currencies Example: iex&gt; Dinero.Currency.all() [ %{code: :USD, name: &quot;United States dollar&quot;}, %{code: :EUR, name: &quot;Euro&quot;}, %{code: :PLN, name: &quot;Zloty&quot;}, %{code: :UAH, name: &quot;Hryvnia&quot;} ]"},{"ref":"Dinero.Currency.html#get!/1","title":"Dinero.Currency.get!/1","type":"function","doc":"Returns a map with the name and code of the currency or raises ArgumentError if currency is not found Example: iex&gt; Dinero.Currency.get!(&quot;USD&quot;) %{code: :USD, name: &quot;United States dollar&quot;} iex&gt; Dinero.Currency.get!(&quot;RUR&quot;) ** (ArgumentError) currency RUR not found"},{"ref":"Dinero.Ecto.DineroWithCurrency.html","title":"Dinero.Ecto.DineroWithCurrency","type":"module","doc":"Provides a custom type for Ecto to save dinero&#39;s amount with currency in database Example Create custom Postrgres type def up do execute &quot;CREATE TYPE public.dinero_with_currency AS (amount integer, currency char(3))&quot; end def down do execute &quot;DROP TYPE public.dinero_with_currency&quot; end Add column to the table alter table (:some_table) do add :price, :dinero_with_currency end Add field to the schema schema &quot;some_table&quot; do field :price, Dinero.Ecto.DineroWithCurrency end"},{"ref":"Dinero.Ecto.DineroWithCurrency.html#cast/1","title":"Dinero.Ecto.DineroWithCurrency.cast/1","type":"function","doc":"Casts the given input to the custom type. This callback is called on external input and can return any type, as long as the dump/1 function is able to convert the returned value into an Ecto native type. There are two situations where this callback is called: When casting values by Ecto.Changeset When passing arguments to Ecto.Query When returning {:error, keyword()}, the returned keyword list will be preserved in the changeset errors, similar to Changeset.add_error/4. Passing a :message key, will override the default message. It is not possible to override the :type key. For {:array, CustomType} or {:map, CustomType} the returned keyword list will be erased and the default error will be shown. Callback implementation for Ecto.Type.cast/1."},{"ref":"Dinero.Ecto.DineroWithCurrency.html#dump/1","title":"Dinero.Ecto.DineroWithCurrency.dump/1","type":"function","doc":"Dumps the given term into an Ecto native type. This callback is called with any term that was stored in the struct and it needs to validate them and convert it to an Ecto native type. Callback implementation for Ecto.Type.dump/1."},{"ref":"Dinero.Ecto.DineroWithCurrency.html#load/1","title":"Dinero.Ecto.DineroWithCurrency.load/1","type":"function","doc":"Loads the given term into a custom type. This callback is called when loading data from the database and receives an Ecto native type. It can return any type, as long as the dump/1 function is able to convert the returned value back into an Ecto native type. Callback implementation for Ecto.Type.load/1."},{"ref":"Dinero.Ecto.DineroWithCurrency.html#type/0","title":"Dinero.Ecto.DineroWithCurrency.type/0","type":"function","doc":"Returns the underlying schema type for the custom type. For example, if you want to provide your own date structures, the type function should return :date. Note this function is not required to return Ecto primitive types, the type is only required to be known by the adapter. Callback implementation for Ecto.Type.type/0."},{"ref":"Dinero.Sigil.html","title":"Dinero.Sigil","type":"module","doc":"Provides sigil to create Dinero struct"},{"ref":"Dinero.Sigil.html#sigil_m/2","title":"Dinero.Sigil.sigil_m/2","type":"macro","doc":"Handles the sigil ~m for Dinero Usage iex&gt; import Dinero.Sigil iex&gt; ~m[100.24]usd %Dinero{amount: 10024, currency: :USD}"},{"ref":"readme.html","title":"Dinero","type":"extras","doc":"Dinero Elixir library for working with Money (slang Dinero)"},{"ref":"readme.html#how-to-use","title":"Dinero - How to use","type":"extras","doc":"ten_bucks = Dinero.new(10, :USD) #%Dinero{amount: 1000, currency: :USD} twelve_bucks = Dinero.new(12, :USD) #%Dinero{amount: 1200, currency: :USD} two_bucks = Dinero.subtract(twenty_bucks, ten_bucks) #%Dinero{amount: 200, currency: :USD} four_bucks = Dinero.multiply(two_bucks, 2) #%Dinero{amount: 400, currency: :USD} convert = Dinero.convert(four_bucks, :UAH, 26.2) #%Dinero{amount: 10480, currency: :UAH} Using with Postgres Dinero.Ecto.DineroWithCurrency is an Ecto type that allows saving amount of dinero with currency to database. Create custom Postrgres type def up do execute &quot;CREATE TYPE public.dinero_with_currency AS (amount integer, currency char(3))&quot; end def down do execute &quot;DROP TYPE public.dinero_with_currency&quot; end Add column to the table alter table (:some_table) do add :price, :dinero_with_currency end Add field to the schema schema &quot;some_table&quot; do field :price, Dinero.Ecto.DineroWithCurrency end Save to DB: iex&gt; Repo.insert %Product{price: Dinero.new(20, :USD)} [debug] QUERY OK db=2.6ms decode=0.5ms queue=0.4ms INSERT INTO &quot;products&quot; (&quot;price&quot;,&quot;inserted_at&quot;,&quot;updated_at&quot;) VALUES ($1,$2,$3) RETURNING &quot;id&quot; [{2000, &quot;USD&quot;}, ~N[2019-07-15 12:47:38], ~N[2019-07-15 12:47:38]] {:ok, %EctoCustomType.Product{ __meta__: #Ecto.Schema.Metadata&lt;:loaded, &quot;products&quot;&gt;, id: 1, inserted_at: ~N[2019-07-15 12:47:38], price: %Dinero{amount: 2000, currency: :USD}, updated_at: ~N[2019-07-15 12:47:38] }} Get from DB: iex&gt; Repo.all(Product) [debug] QUERY OK source=&quot;products&quot; db=1.2ms queue=1.3ms SELECT p0.&quot;id&quot;, p0.&quot;price&quot;, p0.&quot;inserted_at&quot;, p0.&quot;updated_at&quot; FROM &quot;products&quot; AS p0 [] [ %EctoCustomType.Product{ __meta__: #Ecto.Schema.Metadata&lt;:loaded, &quot;products&quot;&gt;, id: 1, inserted_at: ~N[2019-07-15 12:47:38], price: %Dinero{amount: 2000, currency: :USD}, updated_at: ~N[2019-07-15 12:47:38] } ]"},{"ref":"readme.html#installation","title":"Dinero - Installation","type":"extras","doc":"It is available in Hex and can be installed by adding dinero to your list of dependencies in mix.exs: def deps do [ {:dinero, &quot;~&gt; 1.1.0&quot;} ] end Documentation can be found here"},{"ref":"readme.html#authors","title":"Dinero - Authors","type":"extras","doc":"Slava Fir , MLSDev"},{"ref":"readme.html#license","title":"Dinero - License","type":"extras","doc":"Dinero is released under the MIT license. See LICENSE for details."},{"ref":"readme.html#about-mlsdev","title":"Dinero - About MLSDev","type":"extras","doc":"Dinero is maintained by MLSDev, Inc. We specialize in providing all-in-one solution in mobile and web development. Our team follows Lean principles and works according to agile methodologies to deliver the best results reducing the budget for development and its timeline. Find out more here and don&#39;t hesitate to contact us!"}]